@@ -9,8 +9,9 @@
 #include "ufwclient.h"
 #include "ufwlogmodel.h"
 
-#include "rule.h"
-#include "types.h"
+#include <rule.h>
+#include <systemdjob.h>
+#include <types.h>
 
 #include <QDebug>
 #include <QDir>
@@ -65,6 +66,7 @@ void debugState(KAuth::Action::AuthStatus status)
 UfwClient::UfwClient(QObject *parent, const QVariantList &args)
     : IFirewallClientBackend(parent, args)
     , m_rulesModel(new RuleListModel(this))
+    , m_logsAutoRefresh(true)
 {
     queryExecutable("ufw");
 }
@@ -83,7 +85,18 @@ void UfwClient::refresh()
 {
     queryStatus(FirewallClient::DefaultDataBehavior::ReadDefaults, FirewallClient::ProfilesBehavior::ListenProfiles);
 }
+void UfwClient::enableService(bool value)
+{
+    SystemdJob *job = new SystemdJob(static_cast<SYSTEMD::actions>(value), QStringLiteral("ufw.service"), true);
 
+    connect(job, &SystemdJob::result, this, [job] {
+        if (job->error()) {
+            qCDebug(UFWClientDebug) << "SystemdJob Error: " << job->error() << job->errorString();
+            return;
+        }
+    });
+    job->start();
+}
 bool UfwClient::enabled() const
 {
     return m_currentProfile.enabled();
@@ -95,7 +108,7 @@ KJob *UfwClient::setEnabled(bool value)
         return nullptr;
     }
 
-    QVariantMap args {
+    QVariantMap args{
         {"cmd", "setStatus"},
         {"status", value},
     };
@@ -104,9 +117,10 @@ KJob *UfwClient::setEnabled(bool value)
     qCDebug(UFWClientDebug) << "Starting the set Enabled job";
     KAuth::ExecuteJob *job = modifyAction.execute();
 
-    connect(job, &KAuth::ExecuteJob::result, this, [this, job] {
+    connect(job, &KAuth::ExecuteJob::result, this, [this, job, value] {
         qCDebug(UFWClientDebug) << "Set Enabled job finished, triggering a status query.";
         if (job->error() == KJob::NoError) {
+            enableService(value);
             queryStatus(FirewallClient::DefaultDataBehavior::ReadDefaults, FirewallClient::ProfilesBehavior::DontListenProfiles);
         } else {
             qCDebug(UFWClientDebug) << "Job error: " << job->error();
@@ -129,7 +143,7 @@ KJob *UfwClient::queryStatus(FirewallClient::DefaultDataBehavior defaultsBehavio
     const bool readDefaults = defaultsBehavior == FirewallClient::DefaultDataBehavior::ReadDefaults;
     const bool listProfiles = profilesBehavior == FirewallClient::ProfilesBehavior::ListenProfiles;
 
-    QVariantMap args {
+    QVariantMap args{
         {"defaults", readDefaults},
         {"profiles", listProfiles},
     };
@@ -165,7 +179,7 @@ KJob *UfwClient::setDefaultIncomingPolicy(QString policy)
 
     const QString xmlArg = QStringLiteral("<defaults incoming=\"%1\"/>").arg(policy);
 
-    QVariantMap args {
+    QVariantMap args{
         {"cmd", "setDefaults"},
         {"xml", xmlArg},
     };
@@ -191,7 +205,7 @@ KJob *UfwClient::setDefaultOutgoingPolicy(QString policy)
 
     const QString xmlArg = QStringLiteral("<defaults outgoing=\"%1\"/>").arg(policy);
 
-    QVariantMap args {
+    QVariantMap args{
         {"cmd", "setDefaults"},
         {"xml", xmlArg},
     };
@@ -311,13 +325,13 @@ RuleListModel *UfwClient::rules() const
 
 Rule *UfwClient::ruleAt(int index)
 {
-    auto rules = m_currentProfile.rules();
+    auto cRules = m_currentProfile.rules();
 
-    if (index < 0 || index >= rules.count()) {
+    if (index < 0 || index >= cRules.count()) {
         return nullptr;
     }
 
-    Rule *rule = rules.at(index);
+    Rule *rule = cRules.at(index);
     return rule;
 }
 
@@ -328,8 +342,7 @@ KJob *UfwClient::addRule(Rule *r)
         return nullptr;
     }
 
-
-    QVariantMap args {
+    QVariantMap args{
         {"cmd", "addRules"},
         {"count", 1},
         {"xml0", toXml(r)},
@@ -358,14 +371,16 @@ KJob *UfwClient::removeRule(int index)
     // Correct index
     index += 1;
 
-    QVariantMap args {
+    QVariantMap args{
         {"cmd", "removeRule"},
         {"index", QString::number(index)},
     };
 
     KAuth::Action modifyAction = buildModifyAction(args);
     KAuth::ExecuteJob *job = modifyAction.execute();
-    connect(job, &KAuth::ExecuteJob::statusChanged, this, [](KAuth::Action::AuthStatus status) { debugState(status); });
+    connect(job, &KAuth::ExecuteJob::statusChanged, this, [](KAuth::Action::AuthStatus status) {
+        debugState(status);
+    });
 
     connect(job, &KAuth::ExecuteJob::result, this, [this, job] {
         if (!job->error()) {
@@ -386,22 +401,17 @@ KJob *UfwClient::updateRule(Rule *r)
 
 KJob *UfwClient::moveRule(int from, int to)
 {
-    const QVector<Rule*> rules = m_currentProfile.rules();
-    if (from < 0 || from >= rules.count()) {
+    const QVector<Rule *> cRules = m_currentProfile.rules();
+    if (from < 0 || from >= cRules.count()) {
         qWarning() << "invalid from index";
         return nullptr;
     }
 
-    if (to < 0 || to >= rules.count()) {
-        qWarning() << "invalid to index";
-        return nullptr;
-    }
-
     // Correct indices
     from += 1;
     to += 1;
 
-    QVariantMap args {
+    QVariantMap args{
         {"cmd", "moveRule"},
         {"from", from},
         {"to", to},
@@ -445,37 +455,41 @@ bool UfwClient::logsAutoRefresh() const
     return m_logsAutoRefresh;
 }
 
-namespace {
-    bool isNumber(const QString& s) {
-        bool error = true;
-        s.toInt(&error);
-        return error;
+namespace
+{
+bool isNumber(const QString &s)
+{
+    bool error = true;
+    int dummy = s.toInt(&error);
+    Q_UNUSED(dummy)
+    return error;
+}
+
+QString portStrToInt(const QString &portStr)
+{
+    QFile file("/etc/services");
+    if (!file.open(QIODevice::ReadOnly)) {
+        qCDebug(UFWClientDebug) << "Could not open file, returning";
+        return portStr;
     }
-
-    QString portStrToInt(const QString& portStr) {
-        QFile file("/etc/services");
-        if (!file.open(QIODevice::ReadOnly)) {
-            qCDebug(UFWClientDebug) << "Could not open file, returning";
-            return portStr;
+    while (!file.atEnd()) {
+        QString line = file.readLine();
+        if (!line.startsWith(portStr.toLocal8Bit())) {
+            continue;
         }
-        while (!file.atEnd()) {
-            QString line = file.readLine();
-            if (!line.startsWith(portStr.toLocal8Bit())) {
-                continue;
-            }
 
-            // http      80/tcp
-            auto list = line.split(QRegularExpression("\\s+"));
-            if (list.size() > 1) {
-                if (list[1].contains('/')) {
-                    return list[1].split('/')[0];
-                } else {
-                    return list[1];
-                }
+        // http      80/tcp
+        auto list = line.split(QRegularExpression("\\s+"));
+        if (list.size() > 1) {
+            if (list[1].contains('/')) {
+                return list[1].split('/')[0];
+            } else {
+                return list[1];
             }
         }
-        return "";
     }
+    return "";
+}
 }
 
 Rule *UfwClient::createRuleFromConnection(const QString &protocol, const QString &localAddress, const QString &foreignAddres, const QString &status)
@@ -524,7 +538,12 @@ Rule *UfwClient::createRuleFromConnection(const QString &protocol, const QString
     return rule;
 }
 
-Rule *UfwClient::createRuleFromLog(const QString &protocol, const QString &sourceAddress, const QString &sourcePort, const QString &destinationAddress, const QString &destinationPort, const QString &inn)
+Rule *UfwClient::createRuleFromLog(const QString &protocol,
+                                   const QString &sourceAddress,
+                                   const QString &sourcePort,
+                                   const QString &destinationAddress,
+                                   const QString &destinationPort,
+                                   const QString &inn)
 {
     // Transform to the ufw notation
     auto rule = new Rule();
@@ -584,7 +603,8 @@ void UfwClient::refreshProfiles()
     setProfiles(profiles);
 }
 
-QStringList UfwClient::knownProtocols() {
+QStringList UfwClient::knownProtocols()
+{
     return {i18n("Any"), "TCP", "UDP"};
 }
 
@@ -603,6 +623,9 @@ QString UfwClient::toXml(Rule *r) const
 
     xml.writeAttribute(QStringLiteral("action"), Types::toString(r->action()));
     xml.writeAttribute(QStringLiteral("direction"), r->incoming() ? QStringLiteral("in") : QStringLiteral("out"));
+    // ufw doesn't know when to treat a service (simplified rule) as in or out by itself, so we have to hint it the correct
+    // direction.
+    bool hintUFW = r->incoming() && r->simplified();
 
     if (!r->destinationApplication().isEmpty()) {
         xml.writeAttribute(QStringLiteral("dapp"), r->destinationApplication());
@@ -610,9 +633,9 @@ QString UfwClient::toXml(Rule *r) const
         xml.writeAttribute(QStringLiteral("dport"), r->destinationPort());
     }
     if (!r->sourceApplication().isEmpty()) {
-        xml.writeAttribute(QStringLiteral("sapp"), r->sourceApplication());
+        hintUFW ? xml.writeAttribute(QStringLiteral("dapp"), r->sourceApplication()) : xml.writeAttribute(QStringLiteral("sapp"), r->sourceApplication());
     } else if (!r->sourcePort().isEmpty()) {
-        xml.writeAttribute(QStringLiteral("sport"), r->sourcePort());
+        hintUFW ? xml.writeAttribute(QStringLiteral("dport"), r->sourcePort()) : xml.writeAttribute(QStringLiteral("sport"), r->sourcePort());
     }
 
     if (!FirewallClient::isTcpAndUdp(r->protocol())) {
@@ -635,7 +658,6 @@ QString UfwClient::toXml(Rule *r) const
 
     xml.writeAttribute(QStringLiteral("logtype"), Types::toString(r->logging()));
 
-
     xml.writeAttribute(QStringLiteral("v6"), r->ipv6() ? QStringLiteral("True") : QStringLiteral("False"));
 
     xml.writeEndElement();
@@ -646,10 +668,10 @@ QString UfwClient::toXml(Rule *r) const
 bool UfwClient::isCurrentlyLoaded() const
 {
     QProcess process;
-    const QString name = "systemctl";
+    const QString pname = "systemctl";
     const QStringList args = {"status", "ufw"};
 
-    process.start(name, args);
+    process.start(pname, args);
     process.waitForFinished();
 
     // systemctl returns 0 for status if the app is loaded, and 3 otherwise.
@@ -701,6 +723,4 @@ void UfwClient::queryKnownApplications()
     job->start();
 }
 
-
 #include "ufwclient.moc"
-
